@@ -10,7 +10,7 @@
 dodgr_graph_cols <- function (graph) {
 
     nms <- names (graph)
-    component <- grep ("comp", nms) %>% null_to_na ()
+    component <- find_component_col (graph)
     if (methods::is (graph, "dodgr_streetnet") &&
         !methods::is (graph, "dodgr_streetnet_sc") &&
         ncol (graph) >= 11) {
@@ -30,7 +30,7 @@ dodgr_graph_cols <- function (graph) {
         yto <- which (nms %in% c ("yto", "to_lat"))
         if (length (yto) == 0) yto <- NA
     } else {
-        edge_id <- grep ("edge_id|edge_$", nms) %>% null_to_na ()
+        edge_id <- find_edge_id_col(graph)
 
         d_col <- find_d_col (graph)
         w_col <- find_w_col (graph)
@@ -461,7 +461,12 @@ insert_one_edge <- function (graph, index, x, y, gr_cols) {
         y <- (graph [[gr_cols$yfr]] [index] +
             graph [[gr_cols$yto]] [index]) / 2
     }
-    expand_index <- c (1:index, index, (index + 1):nrow (graph))
+    expand_index <- c (
+        seq_len (index),
+        index,
+        seq_len (nrow (graph)) [-seq_len (index)]
+    )
+
     graph <- graph [expand_index, ]
     graph [index, gr_cols$xto] <- x
     graph [index, gr_cols$yto] <- y
