@@ -79,9 +79,6 @@ pre_process_xy <- function (xy) {
         }
     }
 
-    if (is (xy, "tbl")) {
-        xy <- data.frame (xy)
-    }
     if (is (xy, "sf")) {
         if (!"geometry" %in% names (xy)) {
             stop ("xy has no sf geometry column")
@@ -93,6 +90,8 @@ pre_process_xy <- function (xy) {
             matrix (nrow = 2) %>%
             t ()
         xy <- data.frame (x = xy [, 1], y = xy [, 2])
+    } else if (is (xy, "tbl")) {
+        xy <- data.frame (xy)
     } else {
         xyi <- find_xy_col_simple (xy)
         xy <- data.frame (x = xy [, xyi [1]], y = xy [, xyi [2]])
@@ -223,7 +222,7 @@ signed_intersection_dists <- function (graph, xy, res) {
     which_side <- (gxy$xto - gxy$xfr) * (xy_intersect$y - gxy$yfr) -
         (gxy$yto - gxy$yfr) * (xy_intersect$x - gxy$xfr)
     which_side [which_side < 0.0] <- -1
-    which_side [which_side > 0.0] <- 1
+    which_side [which_side >= 0.0] <- 1
 
     return (cbind (d_signed = d * which_side, xy_intersect))
 }
