@@ -1,8 +1,7 @@
 # nocov start
-.onLoad <- function (libname, pkgname)
-{
+.onLoad <- function (libname, pkgname) { # nolint
+
     Sys.setenv ("RCPP_PARALLEL_BACKEND" = "tinythread")
     invisible ()
 }
 # nocov end
-
