@@ -37,6 +37,8 @@ test_that ("sf", {
     expect_identical (gsf1, gsf2)
 
     gc <- dodgr_contract_graph (graph)
-    msg <- "Calling on a contracted graph will result in loss of information"
-    expect_warning (gsf <- dodgr_to_sf (gc), msg)
+    expect_error (
+        suppressWarnings (gsf <- dodgr_to_sf (gc)),
+        "Graph has already been contracted"
+    )
 })
